@@ -1145,16 +1145,16 @@
     const isChromium =
         userAgent.includes("chrome") || userAgent.includes("chromium");
     const isThunderbird = userAgent.includes("thunderbird");
-    const isFirefox = userAgent.includes("firefox") || isThunderbird;
-    const isVivaldi = userAgent.includes("vivaldi");
-    const isYaBrowser = userAgent.includes("yabrowser");
-    const isOpera = userAgent.includes("opr") || userAgent.includes("opera");
-    const isEdge = userAgent.includes("edg");
-    const isSafari = userAgent.includes("safari") && !isChromium;
-    const isWindows = platform.startsWith("win");
-    const isMacOS = platform.startsWith("mac");
-    const isMobile = userAgent.includes("mobile");
-    const chromiumVersion = (() => {
+    userAgent.includes("firefox") || isThunderbird;
+    userAgent.includes("vivaldi");
+    userAgent.includes("yabrowser");
+    userAgent.includes("opr") || userAgent.includes("opera");
+    userAgent.includes("edg");
+    userAgent.includes("safari") && !isChromium;
+    platform.startsWith("win");
+    platform.startsWith("mac");
+    userAgent.includes("mobile");
+    (() => {
         const m = userAgent.match(/chrom[e|ium]\/([^ ]+)/);
         if (m && m[1]) {
             return m[1];
@@ -1162,7 +1162,7 @@
             return "";
         }
     })();
-    const isDefinedSelectorSupported = (() => {
+    (() => {
         try {
             document.querySelector(":defined");
             return true;
@@ -1170,7 +1170,7 @@
             return false;
         }
     })();
-    const isCSSStyleSheetConstructorSupported = (() => {
+    (() => {
         try {
             new CSSStyleSheet();
             return true;
@@ -2058,7 +2058,7 @@
         return code;
     }
 
-    const is12H = new Date().toLocaleTimeString(getUILanguage()).endsWith("M");
+    new Date().toLocaleTimeString(getUILanguage()).endsWith("M");
 
     function isIPV6(url) {
         const openingBracketIndex = url.indexOf("[");
